==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/e0/e0cb1d9ebd416df8c7cd37963e0c083e.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/fresh-left/assets/logo_demo-company-i.svg */
class __TwigTemplate_8f0fccc62d3d40862921af74d08cd827 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?xml version=\"1.0\" encoding=\"utf-8\"?>
<!-- Generator: Adobe Illustrator 21.1.0, SVG Export Plug-In . SVG Version: 6.00 Build 0)  -->
<svg version=\"1.1\" id=\"Layer_1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\"
\t viewBox=\"0 0 300.8 52.1\" style=\"enable-background:new 0 0 300.8 52.1;\" xml:space=\"preserve\">
<style type=\"text/css\">
\t.st0{fill:#46637F;}
\t.st1{fill:#2C3E50;}
</style>
<g>
\t<g>
\t\t<path class=\"st0\" d=\"M21.4,4.9C20,5,19,5.1,18.3,5.4c-0.7,0.3-1.2,0.9-1.6,1.7c-0.4,0.9-0.6,2.3-0.6,4.2v28.5c0,2.8-0.1,5-0.3,6.7
\t\t\tc1.6-0.1,3.4-0.2,5.6-0.2v5.7H0v-4.9c1.3,0,2.4-0.2,3.1-0.5c0.7-0.3,1.2-0.9,1.6-1.7c0.4-0.9,0.6-2.3,0.6-4.2V12.2
\t\t\tc0-2.8,0.1-5,0.3-6.7L0,5.7V0h21.4V4.9z\"/>
\t</g>
\t<g>
\t\t<path class=\"st1\" d=\"M68.1,37.4c-1.6,0.7-3.3,1-5,1c-3.1,0-5.8-1-8.2-3c-0.5-0.4-1-0.9-1.4-1.5c-1.9-2.4-2.9-5-2.9-8
\t\t\tc0-2.3,0.6-4.4,1.7-6.3c1.1-1.9,2.6-3.4,4.6-4.5c1.9-1.1,4-1.7,6.3-1.7c1.7,0,3.4,0.4,5.1,1.1c0.8,0.4,1.9,1.1,2.7,1.8
\t\t\tc0.9,0.7,2.2,0.5,2.9-0.3v0c0.7-0.9,0.6-2.3-0.3-3c-1.2-0.9-2.5-1.6-3.9-2.2c-2.1-0.9-4.3-1.3-6.6-1.3c-3.1,0-6,0.7-8.6,2.2
\t\t\tc-2.6,1.5-4.7,3.4-6.2,6C46.8,20.2,46,22.9,46,26c0,3.1,0.7,5.9,2.2,8.4c1.5,2.5,3.5,4.5,6.1,6c2.6,1.5,5.4,2.2,8.5,2.2
\t\t\tc2.2,0,4.4-0.5,6.6-1.4c1.2-0.5,2.7-1.6,3.9-2.4c1-0.7,1.1-2.1,0.3-3l0,0C73,35.1,71.9,35,71,35.6C70.1,36.2,68.9,37,68.1,37.4z\"
\t\t\t/>
\t\t<path class=\"st1\" d=\"M106.1,11.7c-2.6-1.5-5.5-2.2-8.6-2.2c-3.2,0-6,0.7-8.6,2.2c-2.6,1.5-4.7,3.4-6.2,6c-1.5,2.5-2.3,5.3-2.3,8.3
\t\t\tc0,3,0.8,5.8,2.3,8.4c1.5,2.6,3.6,4.6,6.2,6c2.6,1.5,5.5,2.2,8.6,2.2c3.1,0,6-0.7,8.6-2.2c2.6-1.5,4.7-3.5,6.2-6
\t\t\tc1.5-2.6,2.3-5.3,2.3-8.4c0-3-0.8-5.8-2.3-8.3C110.8,15.1,108.7,13.1,106.1,11.7z M108.3,32.3c-1.1,1.9-2.6,3.4-4.6,4.6
\t\t\tc-1.9,1.1-4,1.7-6.2,1.7c-2.3,0-4.4-0.6-6.3-1.7c-1.9-1.1-3.5-2.7-4.6-4.6c-1.1-1.9-1.7-4-1.7-6.3c0-2.3,0.6-4.4,1.7-6.3
\t\t\tc1.1-1.9,2.7-3.4,4.6-4.5c1.9-1.1,4-1.7,6.3-1.7c2.3,0,4.3,0.6,6.2,1.7c1.9,1.1,3.4,2.6,4.6,4.5c1.1,1.9,1.7,4,1.7,6.3
\t\t\tC110,28.3,109.4,30.4,108.3,32.3z\"/>
\t\t<path class=\"st1\" d=\"M140.8,32.6l-11-21.1c-0.6-1.1-1.7-1.8-2.9-1.8l0,0c-1.8,0-3.3,1.5-3.3,3.3v27.2c0,1.1,0.9,2.1,2.1,2.1h0
\t\t\tc1.1,0,2.1-0.9,2.1-2.1V16.3l11,21.3c0.4,0.7,1.2,1.2,2,1.2l0,0c0.8,0,1.6-0.5,2-1.2l10.9-21.3l0,23.9c0,1.2,0.9,2.1,2.1,2.1l0,0
\t\t\tc1.2,0,2.1-0.9,2.1-2.1V13.1c0-1.8-1.5-3.3-3.3-3.3l0,0c-1.2,0-2.4,0.7-2.9,1.8L140.8,32.6z\"/>
\t\t<path class=\"st1\" d=\"M190.8,12.6c-2.2-1.9-5.4-2.9-9.4-2.9h-10.3c-1.2,0-2.2,1-2.2,2.2V40c0,1.2,1,2.2,2.2,2.2l0,0
\t\t\tc1.2,0,2.2-1,2.2-2.2v-7.9h8.1c4,0,7.2-1,9.4-3s3.3-4.8,3.3-8.4C194.2,17.3,193,14.6,190.8,12.6z M187.6,26.3
\t\t\tc-1.5,1.2-3.6,1.8-6.4,1.8h-7.9V13.8l7.9,0c2.8,0,4.9,0.6,6.4,1.8c1.5,1.2,2.2,2.9,2.2,5.3C189.9,23.2,189.1,25.1,187.6,26.3z\"/>
\t\t<path class=\"st1\" d=\"M209.8,11.9l-12.2,27.4c-0.6,1.4,0.4,3,1.9,3l0,0c0.9,0,1.6-0.5,2-1.3l3.7-8.8l15.3,0.1l3.8,8.7
\t\t\tc0.3,0.8,1.1,1.3,2,1.3h0c1.6,0,2.7-1.6,2-3.1l-12.1-27.3c-0.6-1.3-1.9-2.1-3.3-2.1l0,0C211.6,9.8,210.4,10.6,209.8,11.9z
\t\t\t M207.1,28.2l5.8-13.6l5.9,13.6H207.1z\"/>
\t\t<path class=\"st1\" d=\"M260.3,35l-17.4-23.5c-0.8-1.1-2-1.7-3.3-1.7h-0.2c-1.2,0-2.2,1-2.2,2.2V40c0,1.2,1,2.2,2.2,2.2l0,0
\t\t\tc1.2,0,2.2-1,2.2-2.2V17.1l17.3,23.5c0.8,1.1,2.1,1.7,3.4,1.7h0.1c1.2,0,2.2-1,2.2-2.2V12c0-1.2-1-2.2-2.2-2.2l0,0
\t\t\tc-1.2,0-2.2,1-2.2,2.2V35z\"/>
\t\t<path class=\"st1\" d=\"M297,10.8l-9.3,16.6l-9.5-16.6c-0.4-0.6-1-1-1.7-1h0c-1.5,0-2.5,1.6-1.8,3l10.7,19.6V40c0,1.2,1,2.2,2.2,2.2
\t\t\tl0,0c1.2,0,2.2-1,2.2-2.2v-7.9l10.6-19.4c0.7-1.3-0.2-3-1.8-3l0,0C298.1,9.8,297.4,10.2,297,10.8z\"/>
\t</g>
</g>
</svg>
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/fresh-left/assets/logo_demo-company-i.svg";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/fresh-left/assets/logo_demo-company-i.svg", "/var/www/html/mauticGIT-Test/themes/fresh-left/assets/logo_demo-company-i.svg");
    }
}

==> production-demo-20260214_152721.tar.gz: var/www/html/production-demo/var/tmp/twig/e0/e0cb1d9ebd416df8c7cd37963e0c083e.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/fresh-left/assets/logo_demo-company-i.svg */
class __TwigTemplate_8f0fccc62d3d40862921af74d08cd827 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?xml version=\"1.0\" encoding=\"utf-8\"?>
<!-- Generator: Adobe Illustrator 21.1.0, SVG Export Plug-In . SVG Version: 6.00 Build 0)  -->
<svg version=\"1.1\" id=\"Layer_1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\"
\t viewBox=\"0 0 300.8 52.1\" style=\"enable-background:new 0 0 300.8 52.1;\" xml:space=\"preserve\">
<style type=\"text/css\">
\t.st0{fill:#46637F;}
\t.st1{fill:#2C3E50;}
</style>
<g>
\t<g>
\t\t<path class=\"st0\" d=\"M21.4,4.9C20,5,19,5.1,18.3,5.4c-0.7,0.3-1.2,0.9-1.6,1.7c-0.4,0.9-0.6,2.3-0.6,4.2v28.5c0,2.8-0.1,5-0.3,6.7
\t\t\tc1.6-0.1,3.4-0.2,5.6-0.2v5.7H0v-4.9c1.3,0,2.4-0.2,3.1-0.5c0.7-0.3,1.2-0.9,1.6-1.7c0.4-0.9,0.6-2.3,0.6-4.2V12.2
\t\t\tc0-2.8,0.1-5,0.3-6.7L0,5.7V0h21.4V4.9z\"/>
\t</g>
\t<g>
\t\t<path class=\"st1\" d=\"M68.1,37.4c-1.6,0.7-3.3,1-5,1c-3.1,0-5.8-1-8.2-3c-0.5-0.4-1-0.9-1.4-1.5c-1.9-2.4-2.9-5-2.9-8
\t\t\tc0-2.3,0.6-4.4,1.7-6.3c1.1-1.9,2.6-3.4,4.6-4.5c1.9-1.1,4-1.7,6.3-1.7c1.7,0,3.4,0.4,5.1,1.1c0.8,0.4,1.9,1.1,2.7,1.8
\t\t\tc0.9,0.7,2.2,0.5,2.9-0.3v0c0.7-0.9,0.6-2.3-0.3-3c-1.2-0.9-2.5-1.6-3.9-2.2c-2.1-0.9-4.3-1.3-6.6-1.3c-3.1,0-6,0.7-8.6,2.2
\t\t\tc-2.6,1.5-4.7,3.4-6.2,6C46.8,20.2,46,22.9,46,26c0,3.1,0.7,5.9,2.2,8.4c1.5,2.5,3.5,4.5,6.1,6c2.6,1.5,5.4,2.2,8.5,2.2
\t\t\tc2.2,0,4.4-0.5,6.6-1.4c1.2-0.5,2.7-1.6,3.9-2.4c1-0.7,1.1-2.1,0.3-3l0,0C73,35.1,71.9,35,71,35.6C70.1,36.2,68.9,37,68.1,37.4z\"
\t\t\t/>
\t\t<path class=\"st1\" d=\"M106.1,11.7c-2.6-1.5-5.5-2.2-8.6-2.2c-3.2,0-6,0.7-8.6,2.2c-2.6,1.5-4.7,3.4-6.2,6c-1.5,2.5-2.3,5.3-2.3,8.3
\t\t\tc0,3,0.8,5.8,2.3,8.4c1.5,2.6,3.6,4.6,6.2,6c2.6,1.5,5.5,2.2,8.6,2.2c3.1,0,6-0.7,8.6-2.2c2.6-1.5,4.7-3.5,6.2-6
\t\t\tc1.5-2.6,2.3-5.3,2.3-8.4c0-3-0.8-5.8-2.3-8.3C110.8,15.1,108.7,13.1,106.1,11.7z M108.3,32.3c-1.1,1.9-2.6,3.4-4.6,4.6
\t\t\tc-1.9,1.1-4,1.7-6.2,1.7c-2.3,0-4.4-0.6-6.3-1.7c-1.9-1.1-3.5-2.7-4.6-4.6c-1.1-1.9-1.7-4-1.7-6.3c0-2.3,0.6-4.4,1.7-6.3
\t\t\tc1.1-1.9,2.7-3.4,4.6-4.5c1.9-1.1,4-1.7,6.3-1.7c2.3,0,4.3,0.6,6.2,1.7c1.9,1.1,3.4,2.6,4.6,4.5c1.1,1.9,1.7,4,1.7,6.3
\t\t\tC110,28.3,109.4,30.4,108.3,32.3z\"/>
\t\t<path class=\"st1\" d=\"M140.8,32.6l-11-21.1c-0.6-1.1-1.7-1.8-2.9-1.8l0,0c-1.8,0-3.3,1.5-3.3,3.3v27.2c0,1.1,0.9,2.1,2.1,2.1h0
\t\t\tc1.1,0,2.1-0.9,2.1-2.1V16.3l11,21.3c0.4,0.7,1.2,1.2,2,1.2l0,0c0.8,0,1.6-0.5,2-1.2l10.9-21.3l0,23.9c0,1.2,0.9,2.1,2.1,2.1l0,0
\t\t\tc1.2,0,2.1-0.9,2.1-2.1V13.1c0-1.8-1.5-3.3-3.3-3.3l0,0c-1.2,0-2.4,0.7-2.9,1.8L140.8,32.6z\"/>
\t\t<path class=\"st1\" d=\"M190.8,12.6c-2.2-1.9-5.4-2.9-9.4-2.9h-10.3c-1.2,0-2.2,1-2.2,2.2V40c0,1.2,1,2.2,2.2,2.2l0,0
\t\t\tc1.2,0,2.2-1,2.2-2.2v-7.9h8.1c4,0,7.2-1,9.4-3s3.3-4.8,3.3-8.4C194.2,17.3,193,14.6,190.8,12.6z M187.6,26.3
\t\t\tc-1.5,1.2-3.6,1.8-6.4,1.8h-7.9V13.8l7.9,0c2.8,0,4.9,0.6,6.4,1.8c1.5,1.2,2.2,2.9,2.2,5.3C189.9,23.2,189.1,25.1,187.6,26.3z\"/>
\t\t<path class=\"st1\" d=\"M209.8,11.9l-12.2,27.4c-0.6,1.4,0.4,3,1.9,3l0,0c0.9,0,1.6-0.5,2-1.3l3.7-8.8l15.3,0.1l3.8,8.7
\t\t\tc0.3,0.8,1.1,1.3,2,1.3h0c1.6,0,2.7-1.6,2-3.1l-12.1-27.3c-0.6-1.3-1.9-2.1-3.3-2.1l0,0C211.6,9.8,210.4,10.6,209.8,11.9z
\t\t\t M207.1,28.2l5.8-13.6l5.9,13.6H207.1z\"/>
\t\t<path class=\"st1\" d=\"M260.3,35l-17.4-23.5c-0.8-1.1-2-1.7-3.3-1.7h-0.2c-1.2,0-2.2,1-2.2,2.2V40c0,1.2,1,2.2,2.2,2.2l0,0
\t\t\tc1.2,0,2.2-1,2.2-2.2V17.1l17.3,23.5c0.8,1.1,2.1,1.7,3.4,1.7h0.1c1.2,0,2.2-1,2.2-2.2V12c0-1.2-1-2.2-2.2-2.2l0,0
\t\t\tc-1.2,0-2.2,1-2.2,2.2V35z\"/>
\t\t<path class=\"st1\" d=\"M297,10.8l-9.3,16.6l-9.5-16.6c-0.4-0.6-1-1-1.7-1h0c-1.5,0-2.5,1.6-1.8,3l10.7,19.6V40c0,1.2,1,2.2,2.2,2.2
\t\t\tl0,0c1.2,0,2.2-1,2.2-2.2v-7.9l10.6-19.4c0.7-1.3-0.2-3-1.8-3l0,0C298.1,9.8,297.4,10.2,297,10.8z\"/>
\t</g>
</g>
</svg>
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/fresh-left/assets/logo_demo-company-i.svg";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/fresh-left/assets/logo_demo-company-i.svg", "/var/www/html/production-demo/themes/fresh-left/assets/logo_demo-company-i.svg");
    }
}
